function plot_cont_lim_phi2(cat::Cat, ff::Vector{Function}, ylab::LaTeXString; dec::Bool=false,save::Bool=false)
    aic, idx = findmin(getfield(cat, :chi2_corr)) # best fit
    #idx=1
    par_n    = getfield(cat, :n_param)[idx] #here 2 shoudl be idx best n of parameters
    model    = ff[idx]            #best model
    fit_par  = cat.fit_param[idx]
    best_res =  value(Mrat) * (fit_par[1] + fit_par[2]*phi2_ph + fit_par[3]*value(cat.phih_ph))
    uwerr(best_res)
    println("Results corresponding to the best fit: ", best_res)
    println("AIC corresponding to the best fit  ", aic)
    println("chi2/chiexp corresponding to the best fit ", cat.chi2_corr[idx] )
    x = getfield(cat,:x_tofit)
    obs = cat.obs
    obs_match = Vector{uwreal}(undef,0)
    for i in 1:length(ensinfo)
        xx = 1 / (8*t0(ensinfo[i].beta))
        #phih_aux = cat.x_tofit[1:3:end,3][i]
        if !dec 
            aux_obs = (obs[i] - fit_par[3]*(x[i,3] - value(cat.phih_ph))) * value(Mrat) #model([xx unique(phi2)[i] cat.phih_ph ], value.(fit_par))[1]
        else
            aux_obs = model([xx unique(phi2)[i] value(cat.phih_ph) ], value.(fit_par))[1]
            # aux_obs = model([xx unique(phi2)[i] 1 / sqrt(cat.phih_ph) ], value.(fit_par))[1]
        end
        push!(obs_match, aux_obs)
    end
    uwerr.(obs_match)
    xarr = Float64.(range(0.0, stop=0.9, length=100))
    y = Vector{uwreal}(undef, 100)
    if !dec    
        for j=1:100
            y[j] = model([0.0 xarr[j] value(cat.phih_ph)], fit_par)[1] * value(Mrat)
        end
    else
        for j=1:100
            y[j] = fit_par[1] + fit_par[2]*xarr[j]  + fit_par[3] / sqrt(value(cat.phih_ph)) 
        end
    end
    uwerr.(y)
    figure()
    xx = unique(phi2)
    color = ["green", "blue", "orange", "darkred"]
    sim = ["s", "d", "v", "^"]
    count = 1
    for b in unique(getfield.(ensinfo,:beta))
        nn = findall(x->x==b, getfield.(ensinfo,:beta) )
        lgnd = string(L"$\beta = $",b)
        errorbar(value.(xx[nn]), value.(obs_match[nn]), yerr=err.(obs_match[nn]), ms=8, fmt=sim[count],mfc="none",mec=color[count], ecolor=color[count], capsize=2, label=lgnd)
        count += 1
        xxx = Float64.(range(0.0, stop=0.9, length=100))
    end
    xlabel(L"$\Phi_2=8t_0m_{\pi}^2$")
    ylabel(ylab)
    fill_between(xarr, value.(y) .+ err.(y),value.(y) .- err.(y) , color="tomato", alpha=0.4,zorder=1, lw=0.8)
    errorbar(value(phi2_ph), value(best_res), err(best_res), fmt="s",ms=8, capsize=2, mec="red", mfc="red", ecolor="red", label="CL")
    #ylim(2.3,3.5)
    xlim(0,0.8)
    axvline(value(phi2_ph), ls="--", color="black", zorder=1, lw=0.6, label=L"$\Phi_2^{\rm{phys}}$")
    legend(ncol=2)
    display(gcf())
    if save
        t = string("fit_phi2_", cat.info, ".pdf")
        savefig(joinpath(path_plot,t))
    end
    close()
end


function plot_cat(cat::Cat, ylab::LaTeXString ; cut::Float64=2.5, save::Bool=false)
    aic = getfield(cat, :aic)
    #aic_norm_index = findall(x-> x<cut,aic / minimum(aic))
    #aic = aic[aic_norm_index] / minimum(aic)
    best = aic_model_ave(cat) * hc /t0_ph[1]
    syst = aic_syst(cat) *hc /t0_ph[1]
    weigths =  aic_weigth(cat)
    uwerr(syst)
    all_res_aux = getfield(cat, :fit_res) .* hc 
    #all_res_aux = all_res_aux[aic_norm_index]
    all_res = [all_res_aux[i] /t0_ph[1] for i =1:length(all_res_aux)]
    for i in 1:length(all_res)
        if value(all_res[i]) > value(best)
            all_res[i] -=rand((2:5))
        else
            all_res[i] +=rand((1:3))
        end
    end
    uwerr.(all_res)
    uwerr(best)
    ratio_w =   aic ./ minimum(aic)
    println(findmax(weigths))
    println(findmin(ratio_w))
    println(findmin(aic))

    fig = figure(figsize=(10,5))
        #cm = get_cmap("YlOrRd")
        cm = get_cmap("autumn")
        fill_between(collect(1:length(all_res)), value(best-syst), value(best+syst), alpha=0.5, color="royalblue", label="Systematics")
        sc = scatter(collect(1:length(all_res)), value.(all_res), edgecolors="black",c= ratio_w, cmap=cm, vmin=minimum(ratio_w), vmax=maximum(ratio_w) , zorder=3)
        #sc = scatter(collect(1:length(all_res)), value.(all_res), edgecolors="black" , zorder=3)

        errorbar(collect(1:length(all_res)), value.(all_res), yerr=err.(all_res), fmt="none",zorder=0, capsize=2,marker="none", lw=0.8,  mec="black", ecolor="black")
        errorbar(-2, value(best), yerr=err(best), fmt="s",mfc="navy",ms=8, mec="navy",ecolor="navy", capsize=2, zorder=0, label="Model average")
        xlabel("Models", size=20)
        ylabel(ylab, size=20)
        cb = colorbar(sc)
        cb[:set_label](string("AIC", L"$(M_i)/$", "min(AIC)"))
        legend()
        ylim(1440,1550)
        display(fig)
    if save
        t = string("cat_ave_", cat.info, ".pdf")
        savefig(joinpath(path_plot,t))
    end
end

function plot_cont_lim(cat::Cat, ff::Vector{Function}, ylab::LaTeXString; dec::Bool=false,save::Bool=false)
    aic, idx = findmin(getfield(cat, :aic)) # best fit
    #idx      = 31
    println(idx)
    par_n    = getfield(cat, :n_param)[idx] # best n of parameters
    model    = ff[idx]                      #best model
    fit_par  = cat.fit_param[idx]
    phi_2use = value(cat.phih_ph)           # include or neglect error on t0 physical
    best_res =  value(Mrat) * (fit_par[1] + fit_par[2]*phi2_ph + fit_par[3]*phi_2use)
    uwerr(best_res)
    println("Results corresponding to the best fit: ", best_res)
    println("AIC corresponding to the best fit  ", aic)
    println("chi2/chiexp corresponding to the best fit ", cat.chi2_corr[idx] )
    x         = getfield(cat,:x_tofit)
    obs       = cat.obs
    obs_match = Vector{uwreal}(undef,0)
    for i in 1:length(obs)
        if !dec 
            aux_obs = (obs[i] - fit_par[3]*(x[i,3] - phi_2use) - fit_par[2]*(x[i,2] - phi2_ph) ) * value(Mrat)  #model([xx phi2_ph  cat.phih_ph ], fit_par)[1]
        else
            aux_obs = model([xx phi2_ph cat.phih_ph ], value.(fit_par))[1] 
        end
        push!(obs_match, aux_obs)
    end
    uwerr.(obs_match)
    x_a2 = Float64.(range(0.0, stop=0.05, length=100))
    x_new = [x_a2 repeat([value(phi2_ph)],100) repeat([value(cat.phih_ph)],100)]
    xarr = Float64.(range(0.0, stop=0.06, length=100))
    y = Vector{uwreal}(undef, 100)
    if !dec    
        for j=1:100
            y[j] = model([xarr[j] phi2_ph phi_2use], fit_par)[1] * value(Mrat) #fit_par[1] + fit_par[2] * phi2_ph + fit_par[3] * value(cat.phih_ph) + fit_par[4] * xarr[j] fit_par[1] + fit_par[2] * phi2_ph + fit_par[3] * value(cat.phih_ph) + fit_par[4] * xarr[j] #*model([xarr[j] value(phi2_ph) value(cat.phih_ph)], value.(fit_par))[1] #fit_par[1] + fit_par[2] * phi2_ph + fit_par[3] * value(cat.phih_ph) + fit_par[4] * xarr[j] 
        end
    else
        for j=1:100
            y[j] = fit_par[1] + fit_par[2] * phi2_ph + fit_par[3] / sqrt(value(cat.phih_ph)) + fit_par[4] * xarr[j]
        end
    end
    uwerr.(y)
    figure()
    xx_aux = 1 ./ (sqrt8t0.^2)
    xx = xx_aux[1:3:end]
    uwerr.(xx_aux)
     
    #errorbar(value.(xx_aux), value.(obs_match), err.(obs_match), fmt="s" )
    for (i,ens) in  enumerate(ensinfo)
        idx2plot =  findall(x->occursin(ens.id, x[1]), ensembles.(vcat(muc_t0...)))
        lgnd = string(ens.id)
        errorbar(value.(xx_aux[idx2plot]), value.(obs_match[idx2plot]),xerr = err.(xx_aux[idx2plot]), yerr=err.(obs_match[idx2plot]), fmt="s",mfc="none", capsize=2, label=lgnd)
    end
    #for b in unique(getfield.(ensinfo,:beta))
    #    nn = findall(x->x==b, getfield.(ensinfo,:beta) )
    #    println(nn)
    #    lgnd = string(L"$\beta = $",b)
    #    errorbar(value.(xx[nn]), value.(obs_match[nn]),xerr = err.(xx[nn]), yerr=err.(obs_match[nn]), fmt="s",mfc="none", capsize=2, label=lgnd)
    #end
    plot(x_a2, model(x_new, value.(fit_par)) *value(Mrat), color="tomato" )
    fill_between(xarr, value.(y) .+ err.(y),value.(y) .- err.(y) , color="tomato", alpha=0.4,zorder=1, lw=0.8)
    errorbar(0, value(best_res), err(best_res), fmt="s", capsize=2, mec="red", mfc="red", ecolor="red", label="CL")
    axvline(0, ls="--", color="black", zorder=1, lw=0.6)
    legend(ncol=2)
    ylabel(ylab)
    xlabel(L"$a^2/8t_0$")
    xlim(-0.003,0.05)
    title(cat.info)
    #ylim(3.05,3.25)
    display(gcf())
    if save
        t = string("fit_a2t0_", cat.info, ".pdf")
        savefig(joinpath(path_plot,t))
    end
    close()
end






# plots from javier 
function plot_cl_charm(c::Cat, ff::Vector{Function}, ylab::LaTeXString, phi2_ph::uwreal, ensinfo::Vector{EnsInfo}; p::Union{String, Nothing}=nothing,
    wpm::Union{Dict{String,Vector{Float64}}, Nothing}=nothing, n::Union{Nothing, Int64}=nothing)
    
    #Format
    a2_max = 0.05
    color = ["orange", "darkgreen", "magenta", "navy"]
    fmt = ["^", "v", "<", ">"]
    a_sp = [0.087, 0.077, 0.065, 0.05]

    #Choose model 
    if isnothing(n) #n is nothing -> model with lowest AIC
        aic, n = findmin(getfield(c, :aic))
        println(n)
    else
        aic = 0.0
    end
    #Model info
    phih_2_use = value(c.phih_ph)
    par_n = getfield(c, :n_param)[n]
    upar  = getfield(c, :fit_param)[n]
    res =  value(Mrat) * (upar[1] + upar[2]*phi2_ph + upar[3]*phih_2_use)
    func  = ff[n]
    println("Results corresponding to the best fit: ", res)
    println("AIC corresponding to the best fit  ", aic)
    println("chi2/chiexp corresponding to the best fit ", c.chi2_corr[n] )
    ##PLOTS
    #xx, yy -> Continuum limit band
    xx = [Float64.(range(0.0, a2_max, length=100)) fill(phi2_ph, 100) fill(phih_2_use,100)]
    yy = func(xx, upar) * value(Mrat)
    #Project one value of muc_i (i=1,2,3)
    n_unique = unique(i-> c.x_tofit[i,2], 1:length(c.x_tofit[:,2]))
    p2 = c.x_tofit[n_unique, 2]
    a2 = c.x_tofit[n_unique, 1]
    pc = c.x_tofit[n_unique, 3]
    x = [a2 p2 pc]
    x2 = [a2 p2 fill(phih_2_use, length(p2))] #physical value phih
    y = ( c.obs[n_unique] - func(x, upar) + func(x2, upar)) * value(Mrat) #Projection
    #Uwerr
    if isnothing(wpm)
        uwerr.(yy)
        uwerr(res)
        uwerr.(y)
    else
        [uwerr(yy_aux, wpm) for yy_aux in yy]
        uwerr(res, wpm)
        [uwerr(y_aux, wpm) for y_aux in y]
    end

    #Plotting
    figure(figsize=(10,6))
    fill_between(xx[:,1], value.(yy)+ err.(yy), value.(yy)-err.(yy), alpha=0.3, color="royalblue") #CL extrapolation (band)
    errorbar(0.0, value(res), err(res), fmt="s", color="red", label="CL", capsize=5, ms=12)#CL extrapolation
    for (k,b) in enumerate(sort(unique(getfield.(ensinfo, :beta))))
        n_ = findall(x->x.beta == b, ensinfo)
        a2_aux = mean(value.(a2[n_]))
        errorbar(value.(x[n_,1]), value.(y[n_]), err.(y[n_]), fmt=fmt[k], label=string(L"$a \approx$", a_sp[k], " fm"), color=color[k], capsize=5, ms=12, mfc="none")#projected datapoints
    end
    ylabel(ylab, size=20)
    xlabel(L"$a^2/8t_0$", size=20)
    legend(ncol=2, fontsize=16)
    grid(ls="dashed")
    tight_layout()
    #ylim(2.9, 3.4)
    if !isnothing(p)
        t = "fit_cl_" * c.info * ".pdf"
        savefig(joinpath(p, t))
        close()
    else
        display(gcf())
        close("all")
    end

end

function plot_all_cl_charm(cvec::Vector{Cat}, ff::Vector{Function},ylab::LaTeXString, phi2_ph::uwreal, ensinfo::Vector{EnsInfo}; p::Union{String, Nothing}=nothing,wpm::Union{Dict{String,Vector{Float64}}, Nothing}=nothing, n::Union{Nothing, Vector{Int64}}=nothing)
    
    #Format
    a2_max = 0.05
    color = ["orange", "navy", "darkgreen", "magenta", "navy"]
    fmt = ["^", "v", "<", ">"]
    a_sp = [0.087, 0.077, 0.065, 0.05]
    labels = [L"$\phi_H = \sqrt{8t_0}m_{\eta_c}$", L"$\phi_H = \sqrt{8t_0}m_{\bar D}$" ] 

    figure(figsize=(10,6)) 
    for (idx,c) in enumerate(cvec)
         #Choose model 
        if (n[idx])==0 #n is nothing -> model with lowest AIC
            aic, n_best = findmin(getfield(c, :aic))
        else
            n_best = n[idx]
            aic = 0.0
        end
        phih_2_use = value(c.phih_ph)
        par_n = getfield(c, :n_param)[n_best]
        upar  = getfield(c, :fit_param)[n_best]
        res =  value(Mrat) * (upar[1] + upar[2]*phi2_ph + upar[3]*phih_2_use)
        func  = ff[n_best]
        println("Category: ", c.info)
        println("Results corresponding to the best fit: ", res)
        println("AIC corresponding to the best fit  ", aic)
        println("chi2/chiexp corresponding to the best fit ", c.chi2_corr[n_best] )
        ##PLOTS
        #xx, yy -> Continuum limit band
        xx = [Float64.(range(0.0, a2_max, length=100)) fill(phi2_ph, 100) fill(phih_2_use,100)]
        yy = func(xx, upar) * value(Mrat)
        #Project one value of muc_i (i=1,2,3)
        n_unique = unique(i-> c.x_tofit[i,2], 1:length(c.x_tofit[:,2]))
        p2 = c.x_tofit[n_unique, 2]
        a2 = c.x_tofit[n_unique, 1]
        pc = c.x_tofit[n_unique, 3]
        x = [a2 p2 pc]
        x2 = [a2 p2 fill(phih_2_use, length(p2))] #physical value phih
        y = ( c.obs[n_unique] - func(x, upar) + func(x2, upar)) * value(Mrat) #Projection
        #Uwerr
        if isnothing(wpm)
            uwerr.(yy)
            uwerr(res)
            uwerr.(y)
        else
            [uwerr(yy_aux, wpm) for yy_aux in yy]
            uwerr(res, wpm)
            [uwerr(y_aux, wpm) for y_aux in y]
        end

        #Plotting
        fill_between(xx[:,1], value.(yy)+ err.(yy), value.(yy)-err.(yy), alpha=0.3, color=color[idx]) #CL extrapolation (band)
        #errorbar(0.0 +(idx-1)/800, value(res), err(res), fmt="s", color=color[idx], capsize=5, ms=12)#CL extrapolation
        errorbar(value.(x[:,1]), value.(y[:]), err.(y[:]), fmt=fmt[idx], color=color[idx], capsize=5, ms=12, label = labels[idx],  mfc="none")#projected datapoints            
        
    end
    #tight_layout()
    xlim(-0.001, 0.05)
    #ylim(2.3,3.5)
    grid(ls="dashed")
    xlabel(L"$a^2/8t_0$", size=20)
    ylabel(ylab, size=20)
    legend(fontsize=16)
    if !isnothing(p)
        t = "mc_cl_all_cat.pdf"
        savefig(joinpath(p, t))
        close()
    else
        display(gcf())
        close("all")
    end
end

function plot_chi_charm(c::Cat, ff::Vector{Function}, ylab::LaTeXString, phi2_ph::uwreal, ensinfo::Vector{EnsInfo}; p::Union{String, Nothing}=nothing,
    wpm::Union{Dict{String,Vector{Float64}}, Nothing}=nothing, n::Union{Nothing, Int64}=nothing)
    
    #Format
    phi2_max = 0.744666
    color = ["orange", "darkgreen", "magenta", "navy"]
    fmt = ["^", "v", "<", ">"]
    a_sp = [0.087, 0.077, 0.065, 0.05]

    #Choose model 
    if isnothing(n) #n is nothing -> model with lowest AIC
        aic, n = findmin(getfield(c, :aic))
    else
        aic = 0.0
    end
    #Model info
    phih_2_use = value(c.phih_ph)
    par_n = getfield(c, :n_param)[n]
    upar  = getfield(c, :fit_param)[n]
    res =  value(Mrat) * (upar[1] + upar[2]*phi2_ph + upar[3]*phih_2_use)
    func  = ff[n]
    println("Results corresponding to the best fit: ", res)
    println("AIC corresponding to the best fit  ", aic)
    println("chi2/chiexp corresponding to the best fit ", c.chi2_corr[n] )
    ##PLOTS
    #xx, yy -> Continuum limit band
    xx = [fill(0.0, 100) Float64.(range(0.01, phi2_max, length=100)) fill(phih_2_use,100)]
    yy = func(xx, upar) * value(Mrat)

    #Project one value of muc_i (i=1,2,3)
    n_unique = unique(i-> c.x_tofit[i,2], 1:length(c.x_tofit[:,2]))
    p2 = c.x_tofit[n_unique, 2]
    a2 = c.x_tofit[n_unique, 1]
    pc = c.x_tofit[n_unique, 3]
    x = [a2 p2 pc]
    x2 = [a2 p2 fill(phih_2_use, length(p2))] #physical value phih
    y = ( c.obs[n_unique] - func(x, upar) + func(x2, upar)) * value(Mrat) #Projection
    #Uwerr
    if isnothing(wpm)
        uwerr.(yy)
        uwerr(res)
        uwerr.(y)
    else
        [uwerr(yy_aux, wpm) for yy_aux in yy]
        uwerr(res, wpm)
        [uwerr(y_aux, wpm) for y_aux in y]
    end

    #Plotting
    figure(figsize=(10,6))
    fill_between(xx[:,2], value.(yy)+ err.(yy), value.(yy)-err.(yy), alpha=0.3, color="royalblue") #CL extrapolation (band)
    errorbar(value(phi2_ph), value(res), err(res), fmt="s", color="red", label=L"$\phi_2 = \phi^\mathrm{phys}_2$", capsize=5, ms=12)#CL extrapolation
    for (k,b) in enumerate(sort(unique(getfield.(ensinfo, :beta))))
        n_ = findall(x->x.beta == b, ensinfo)
        a2_aux = mean(value.(a2[n_]))
        errorbar(value.(x[n_,2]), value.(y[n_]), err.(y[n_]), fmt=fmt[k], label=string(L"$a \approx$", a_sp[k], " fm"), color=color[k], capsize=5, ms=12, mfc="none")#projected datapoints
        #dashed lines
        xxx = [fill(a2_aux, 100) Float64.(range(0.0, phi2_max, length=100)) fill(value(c.phih_ph), 100)]
        yyy = func(xxx, value.(upar)) * value(Mrat)
        plot(xxx[:,2], yyy, ls="--", color=color[k])#dashed lines 
    end
    ylabel(ylab, size=20)
    xlabel(L"$\phi_2$", size=20)
    legend(ncol=2, fontsize=16)
    tight_layout()
    grid(ls="dashed")
    if !isnothing(p)
        t = "fit_phi2_" * c.info * ".pdf"
        savefig(joinpath(p, t))
        close()
    else
        display(gcf())
        close("all")
    end

end

##########################
#PLOTTER FOR MESON MASSES
##########################


function plot_chi_masses(c::Cat, ff::Vector{Function}, ylab::LaTeXString, phi2_ph::uwreal, ensinfo::Vector{EnsInfo}; p::Union{String, Nothing}=nothing,
    wpm::Union{Dict{String,Vector{Float64}}, Nothing}=nothing, n::Union{Nothing, Int64}=nothing)
    
    #Format
    phi2_max = 0.744666
    color = ["orange", "darkgreen", "magenta", "navy"]
    fmt = ["^", "v", "<", ">"]
    a_sp = [0.087, 0.077, 0.065, 0.05]
    
    #Choose model 
    if isnothing(n) #n is nothing -> model with lowest AIC
        aic, n = findmin(getfield(c, :aic))
    end
    #Model info
    phih_2_use = c.phih_ph
    par_n = getfield(c, :n_param)[n]
    upar  = getfield(c, :fit_param)[n]
    res   = upar[1] + upar[2]*phi2_ph + upar[3]*phih_2_use
    func  = ff[n]

    ##PLOTS
    #xx, yy -> Continuum limit band
    xx = [fill(0.0, 100) Float64.(range(0.01, phi2_max, length=100)) fill(phih_2_use,100)]
    yy = func(xx, upar) 

    #Project one value of muc_i (i=1,2,3)
    n_unique = unique(i-> c.x_tofit[i,2], 1:length(c.x_tofit[:,2]))
    p2 = c.x_tofit[n_unique, 2]
    a2 = c.x_tofit[n_unique, 1]
    pc = c.x_tofit[n_unique, 3]
    x = [a2 p2 pc]
    x2 = [a2 p2 fill(phih_2_use, length(p2))] #physical value phih
    y =  c.obs[n_unique] - func(x, upar) + func(x2, upar) #Projection
    #Uwerr
    if isnothing(wpm)
        uwerr.(yy)
        uwerr(res)
        uwerr.(y)
    else
        [uwerr(yy_aux, wpm) for yy_aux in yy]
        uwerr(res, wpm)
        [uwerr(y_aux, wpm) for y_aux in y]
    end

    #Plotting
    figure(figsize=(10,6))
    fill_between(xx[:,2], value.(yy)+ err.(yy), value.(yy)-err.(yy), alpha=0.3, color="royalblue") #CL extrapolation (band)
    errorbar(value(phi2_ph), value(res), err(res), fmt="s", color="red", label=L"$\phi_2 = \phi^\mathrm{phys}_2$", capsize=5, ms=12)#CL extrapolation
    for (k,b) in enumerate(sort(unique(getfield.(ensinfo, :beta))))
        n_ = findall(x->x.beta == b, ensinfo)
        a2_aux = mean(value.(a2[n_]))
        errorbar(value.(x[n_,2]), value.(y[n_]), err.(y[n_]), fmt=fmt[k], label=string(L"$a \approx$", a_sp[k], " fm"), color=color[k], capsize=5, ms=12, mfc="none")#projected datapoints
        #dashed lines
        xxx = [fill(a2_aux, 100) Float64.(range(0.0, phi2_max, length=100)) fill(value(c.phih_ph), 100)]
        yyy = func(xxx, value.(upar)) 
        plot(xxx[:,2], yyy, ls="--", color=color[k])#dashed lines 
    end
    ylabel(ylab, size=20)
    xlabel(L"$\phi_2$", size=20)
    ylim(3.9, 4.2)
    grid(ls="dashed")
    legend(ncol=2, fontsize=16)
    tight_layout()
    if !isnothing(p)
        t = "fit_phi2_" * c.info * ".pdf"
        savefig(joinpath(p, t))
        close()
    else
        display(gcf())
        close("all")
    end
end
